@@ -6,7 +6,7 @@ require 'concurrent/actor'
 require 'concurrent/agent'
 require 'concurrent/channel'
 require 'concurrent/lazy_register'
-require 'concurrent/executor/wrapping_executor' if Concurrent.ruby_version :>=, 2, 1, 0
+require 'concurrent/executor/wrapping_executor'
 
 require 'concurrent/edge/lock_free_linked_set'
 require 'concurrent/edge/lock_free_queue'
@@ -16,4 +16,4 @@ require 'concurrent/edge/throttle'
 require 'concurrent/edge/channel'
 
 require 'concurrent/edge/processing_actor'
-require 'concurrent/edge/erlang_actor' if Concurrent.ruby_version :>=, 2, 1, 0
+require 'concurrent/edge/erlang_actor'
