@@ -1,6 +1,10 @@
-if Concurrent.ruby_version :<, 2, 1, 0
-  raise 'ErlangActor requires at least ruby version 2.1'
-end
+require 'set'
+require 'concurrent/atomic/count_down_latch'
+require 'concurrent/concern/logging'
+require 'concurrent/edge/channel'
+require 'concurrent/errors'
+require 'concurrent/promises'
+require 'concurrent/synchronization/object'
 
 module Concurrent
 
