@@ -8,6 +8,6 @@ module Concurrent
 
     subject { SerializedExecutionDelegator.new(ImmediateExecutor.new) }
 
-    it_should_behave_like :executor_service
+    it_should_behave_like :executor_service, immediate_type: true
   end
 end
